@@ -2,6 +2,7 @@ from tunas2dsdl.generator.generate import Generation
 from tunas2dsdl.parser import DetectionParse
 from .general.classdomain import ClassDomain, Label
 from .general.struct import Struct, Field
+from .general import OptionEatAll
 
 __all__ = [
     "Generation",
@@ -10,4 +11,5 @@ __all__ = [
     "Label",
     "Struct",
     "Field",
+    "OptionEatAll",
 ]
