@@ -16,20 +16,24 @@ class Field:
 
     def __init__(self, name, field_value=None, field_type=None, is_attr=None, param=None):
         self._name = name
-
         self._is_attr = is_attr
+        self.param = param
+        self.arg = None
         if field_type is not None:
             self.field_type = self.FIELD_MAPPING[field_type]
         elif field_value is not None:
             self.field_type = self.FIELD_MAPPING[field_value.__class__.__name__]
+            if self.field_type == "List":
+                self.arg = "etype"
+                self.param = self.FIELD_MAPPING[field_value[0].__class__.__name__]
         else:
             raise RuntimeError("not supported field type")
-        self.arg = None
         if field_type == "category":
             self.arg = "dom"
+            assert isinstance(self.param, str)
         elif field_type == "list":
             self.arg = "etype"
-        self.param = param
+            assert isinstance(self.param, str)
 
     @property
     def is_attr(self):
