@@ -1,7 +1,5 @@
 import json
-from ..general import ClassDomain, Label
-from ..general import Field, Struct
-from ..general import DataSample
+from ..general import ClassDomain, Label, Field, Struct, DataSample, Util
 from tqdm import tqdm
 from ..io import HardDiskBackend, FileIO
 
@@ -76,8 +74,6 @@ class DetectionParse:
         sample_struct = Struct("ObjectDetectionSample")
         media_field = Field("media", field_type="media")
         sample_struct.add_field(media_field)  # 添加图像field
-        annotation_field = Field("annotations", field_type="list", param=object_struct.as_others_param(sample_struct))
-        sample_struct.add_field(annotation_field)  # 添加annotation field
         sample_container = DataSample(sample_struct, self._class_domain)
 
         for sample in tqdm(samples, desc="parsing samples ...."):
@@ -115,17 +111,21 @@ class DetectionParse:
                 else:
                     continue
                 # 创建LabelField并将值装进gt_item里面
-                label_field = Field("category", field_type="category", param=f"${object_struct.ARG}")
-                object_struct.add_field(label_field)
-                category_id = gt.pop("categories")[0]["category_id"]
-                category_name = self.raw_class_info[gt_type][category_id]  # 拿到category_name
-                gt_item["category"] = self._class_domain.index(category_name)
+                if 'categories' in gt and len(gt['categories']) > 0:
+                    label_field = Field("category", field_type="category", param=f"${object_struct.ARG}")
+                    object_struct.add_field(label_field)
+                    category_id = gt.pop("categories")[0]["category_id"]
+                    category_name = self.raw_class_info[gt_type][category_id]  # 拿到category_name
+                    gt_item["category"] = self._class_domain.index(category_name)
+
                 attributes = gt.pop("attributes", {})
                 for attr_k, attr_v in attributes.items():
+                    attr_k = Util.clean(attr_k)
                     attr_field = Field(attr_k, field_value=attr_v, is_attr=True)
                     object_struct.add_field(attr_field, optional=True)
                     gt_item[attr_k] = attr_v
                 for other_k, other_v in gt.items():
+                    other_k = Util.clean(other_k)
                     other_field = Field(other_k, field_value=other_v, is_attr=True)
                     object_struct.add_field(other_field)
                     gt_item[other_k] = other_v
